@@ -1,4 +1,6 @@
 pub (crate) mod hosted_service;
 pub (crate) mod hosted_service_start_timeout;
 pub (crate) mod hosted_service_stop_timeout;
-pub (crate) mod background_service;
\ No newline at end of file
+pub (crate) mod background_service;
+pub (crate) mod background_service_with_startup;
+pub (crate) mod background_service_from_ioc;
\ No newline at end of file
